@@ -268,6 +268,23 @@ static const Itdb_IpodInfo ipod_info_table [] = {
     {"C074",  16, ITDB_IPOD_MODEL_NANO_RED,       ITDB_IPOD_GENERATION_NANO_5, 14},
     {"C075",  16, ITDB_IPOD_MODEL_NANO_PINK,      ITDB_IPOD_GENERATION_NANO_5, 14},
 
+    /* iPod nano touch (Sixth Generation) */
+    {"C525",   8, ITDB_IPOD_MODEL_NANO_SILVER,    ITDB_IPOD_GENERATION_NANO_6, 14},
+    {"C688",   8, ITDB_IPOD_MODEL_NANO_BLACK,     ITDB_IPOD_GENERATION_NANO_6, 14},
+    {"C689",   8, ITDB_IPOD_MODEL_NANO_BLUE,      ITDB_IPOD_GENERATION_NANO_6, 14},
+    {"C690",   8, ITDB_IPOD_MODEL_NANO_GREEN,     ITDB_IPOD_GENERATION_NANO_6, 14},
+    {"C691",   8, ITDB_IPOD_MODEL_NANO_ORANGE,    ITDB_IPOD_GENERATION_NANO_6, 14},
+    {"C692",   8, ITDB_IPOD_MODEL_NANO_PINK,      ITDB_IPOD_GENERATION_NANO_6, 14},
+    {"C693",   8, ITDB_IPOD_MODEL_NANO_RED,       ITDB_IPOD_GENERATION_NANO_6, 14},
+
+    {"C526",  16, ITDB_IPOD_MODEL_NANO_SILVER,    ITDB_IPOD_GENERATION_NANO_6, 14},
+    {"C694",  16, ITDB_IPOD_MODEL_NANO_BLACK,     ITDB_IPOD_GENERATION_NANO_6, 14},
+    {"C695",  16, ITDB_IPOD_MODEL_NANO_BLUE,      ITDB_IPOD_GENERATION_NANO_6, 14},
+    {"C696",  16, ITDB_IPOD_MODEL_NANO_GREEN,     ITDB_IPOD_GENERATION_NANO_6, 14},
+    {"C697",  16, ITDB_IPOD_MODEL_NANO_ORANGE,    ITDB_IPOD_GENERATION_NANO_6, 14},
+    {"C698",  16, ITDB_IPOD_MODEL_NANO_PINK,      ITDB_IPOD_GENERATION_NANO_6, 14},
+    {"C699",  16, ITDB_IPOD_MODEL_NANO_RED,       ITDB_IPOD_GENERATION_NANO_6, 14},
+
     /* iPod Touch 1st gen */
     {"A623",   8, ITDB_IPOD_MODEL_TOUCH_SILVER,   ITDB_IPOD_GENERATION_TOUCH_1, 50},
     {"A627",  16, ITDB_IPOD_MODEL_TOUCH_SILVER,   ITDB_IPOD_GENERATION_TOUCH_1, 50},
@@ -286,6 +303,11 @@ static const Itdb_IpodInfo ipod_info_table [] = {
     {"C008",  32, ITDB_IPOD_MODEL_TOUCH_SILVER,   ITDB_IPOD_GENERATION_TOUCH_3, 50},
     {"C011",  64, ITDB_IPOD_MODEL_TOUCH_SILVER,   ITDB_IPOD_GENERATION_TOUCH_3, 50},
 
+    /* iPod Touch 4th gen */
+    {"C540",   8, ITDB_IPOD_MODEL_TOUCH_SILVER,   ITDB_IPOD_GENERATION_TOUCH_4, 50},
+    {"C544",  32, ITDB_IPOD_MODEL_TOUCH_SILVER,   ITDB_IPOD_GENERATION_TOUCH_4, 50},
+    {"C547",  64, ITDB_IPOD_MODEL_TOUCH_SILVER,   ITDB_IPOD_GENERATION_TOUCH_4, 50},
+
     /* iPhone */
     {"A501",   4, ITDB_IPOD_MODEL_IPHONE_1,       ITDB_IPOD_GENERATION_IPHONE_1, 50},
     {"A712",   8, ITDB_IPOD_MODEL_IPHONE_1,       ITDB_IPOD_GENERATION_IPHONE_1, 50},
@@ -672,6 +694,7 @@ static const ItdbSerialToModel serial_to_model_mapping[] = {
     { "YX7", "B228" }, /* 1GB Blue Shuffle 2g */
     { "YX9", "B225" }, /* 1GB Silver Shuffle 2g */
     { "8CQ", "C167" }, /* 1GB Gold Shuffle 2g */
+    { "1ZH", "B518" }, /* 2GB Silver Shuffle 2g */
     { "UNA", "A350" },
     { "UNB", "A350" },
     { "UPR", "A352" },
@@ -791,6 +814,8 @@ static const ItdbSerialToModel serial_to_model_mapping[] = {
     { "73A", "C074" }, /* 16GB Red Nano 5g */
     { "73B", "C075" }, /* 16GB Pink Nano 5g */
 
+    { "CMN", "C525" }, /* 8GB Silver Nano 6g */
+
     { "A1S", "C306" }, /* 2GB Silver Shuffle 4g */
     { "A78", "C323" }, /* 2GB Black Shuffle 4g */
     { "ALB", "C381" }, /* 2GB Green Shuffle 4g */
@@ -808,9 +833,11 @@ static const ItdbSerialToModel serial_to_model_mapping[] = {
     { "0JW", "B376" }, /* 32GB Silver iPod Touch (1st gen) */
     { "201", "B528" }, /* 8GB Silver iPod Touch (2nd gen) */
     { "203", "B531" }, /* 16GB Silver iPod Touch (2nd gen) */
-    { "75J", "C086" }, /* 8GB Silver iPod Touch (3rd gen) */
-    { "6K2", "C008" }, /* 32GB Silver iPod Touch (3rd gen) */
-    { "6K4", "C011" }, /* 64GB Silver iPod Touch (3rd gen) */
+    { "75J", "C086" }, /* 8GB iPod Touch (3rd gen) */
+    { "6K2", "C008" }, /* 32GB iPod Touch (3rd gen) */
+    { "6K4", "C011" }, /* 64GB iPod Touch (3rd gen) */
+    { "CP7", "C540" }, /* 8GB iPod Touch (4th gen) */
+    { "CP9", "C544" }, /* 32GB iPod Touch (4th gen) */
 
     { "VR0", "A501" }, /* 4GB Silver iPhone 1st gen */
     { "WH8", "A712" }, /* 8GB Silver iPhone */
@@ -1338,9 +1365,11 @@ itdb_device_supports_sqlite_db (const Itdb_Device *device)
 	    case ITDB_IPOD_GENERATION_CLASSIC_3:
 		return FALSE;
 	    case ITDB_IPOD_GENERATION_NANO_5:
+	    case ITDB_IPOD_GENERATION_NANO_6:
 	    case ITDB_IPOD_GENERATION_TOUCH_1:
 	    case ITDB_IPOD_GENERATION_TOUCH_2:
 	    case ITDB_IPOD_GENERATION_TOUCH_3:
+	    case ITDB_IPOD_GENERATION_TOUCH_4:
 	    case ITDB_IPOD_GENERATION_IPHONE_1:
 	    case ITDB_IPOD_GENERATION_IPHONE_2:
 	    case ITDB_IPOD_GENERATION_IPHONE_3:
@@ -1396,12 +1425,14 @@ itdb_device_supports_sparse_artwork (const Itdb_Device *device)
             case ITDB_IPOD_GENERATION_NANO_3:
             case ITDB_IPOD_GENERATION_NANO_4:
             case ITDB_IPOD_GENERATION_NANO_5:
+            case ITDB_IPOD_GENERATION_NANO_6:
             case ITDB_IPOD_GENERATION_CLASSIC_1:
             case ITDB_IPOD_GENERATION_CLASSIC_2:
             case ITDB_IPOD_GENERATION_CLASSIC_3:
             case ITDB_IPOD_GENERATION_TOUCH_1:
             case ITDB_IPOD_GENERATION_TOUCH_2:
             case ITDB_IPOD_GENERATION_TOUCH_3:
+            case ITDB_IPOD_GENERATION_TOUCH_4:
             case ITDB_IPOD_GENERATION_IPHONE_1:
             case ITDB_IPOD_GENERATION_IPHONE_2:
             case ITDB_IPOD_GENERATION_IPHONE_3:
@@ -1700,6 +1731,7 @@ gboolean itdb_device_supports_video (const Itdb_Device *device)
         case ITDB_IPOD_GENERATION_SHUFFLE_4:
         case ITDB_IPOD_GENERATION_NANO_1:
         case ITDB_IPOD_GENERATION_NANO_2:
+        case ITDB_IPOD_GENERATION_NANO_6:
             return FALSE;
         case ITDB_IPOD_GENERATION_NANO_3:
         case ITDB_IPOD_GENERATION_NANO_4:
@@ -1712,6 +1744,7 @@ gboolean itdb_device_supports_video (const Itdb_Device *device)
 	case ITDB_IPOD_GENERATION_TOUCH_1:
 	case ITDB_IPOD_GENERATION_TOUCH_2:
 	case ITDB_IPOD_GENERATION_TOUCH_3:
+	case ITDB_IPOD_GENERATION_TOUCH_4:
 	case ITDB_IPOD_GENERATION_IPHONE_1:
 	case ITDB_IPOD_GENERATION_IPHONE_2:
 	case ITDB_IPOD_GENERATION_IPHONE_3:
@@ -1838,6 +1871,8 @@ ItdbChecksumType itdb_device_get_checksum_type (const Itdb_Device *device)
 
 	    case ITDB_IPOD_GENERATION_IPAD_1:
 	    case ITDB_IPOD_GENERATION_IPHONE_4:
+	    case ITDB_IPOD_GENERATION_TOUCH_4:
+	    case ITDB_IPOD_GENERATION_NANO_6:
 		return ITDB_CHECKSUM_HASHAB;
 
 	    case ITDB_IPOD_GENERATION_UNKNOWN:
@@ -2063,6 +2098,7 @@ itdb_device_supports_podcast (const Itdb_Device *device)
 	    case ITDB_IPOD_GENERATION_NANO_3:
 	    case ITDB_IPOD_GENERATION_NANO_4:
 	    case ITDB_IPOD_GENERATION_NANO_5:
+	    case ITDB_IPOD_GENERATION_NANO_6:
 	    case ITDB_IPOD_GENERATION_SHUFFLE_1:
 	    case ITDB_IPOD_GENERATION_SHUFFLE_2:
 	    case ITDB_IPOD_GENERATION_SHUFFLE_3:
@@ -2075,6 +2111,7 @@ itdb_device_supports_podcast (const Itdb_Device *device)
 	    case ITDB_IPOD_GENERATION_TOUCH_1:
 	    case ITDB_IPOD_GENERATION_TOUCH_2:
 	    case ITDB_IPOD_GENERATION_TOUCH_3:
+	    case ITDB_IPOD_GENERATION_TOUCH_4:
 	    case ITDB_IPOD_GENERATION_IPHONE_1:
 	    case ITDB_IPOD_GENERATION_IPHONE_2:
 	    case ITDB_IPOD_GENERATION_IPHONE_3:
@@ -2111,6 +2148,7 @@ gboolean itdb_device_is_shuffle (const Itdb_Device *device)
         case ITDB_IPOD_GENERATION_NANO_3:
         case ITDB_IPOD_GENERATION_NANO_4:
         case ITDB_IPOD_GENERATION_NANO_5:
+        case ITDB_IPOD_GENERATION_NANO_6:
         case ITDB_IPOD_GENERATION_VIDEO_1:
         case ITDB_IPOD_GENERATION_VIDEO_2:
         case ITDB_IPOD_GENERATION_CLASSIC_1:
@@ -2119,6 +2157,7 @@ gboolean itdb_device_is_shuffle (const Itdb_Device *device)
         case ITDB_IPOD_GENERATION_TOUCH_1:
         case ITDB_IPOD_GENERATION_TOUCH_2:
         case ITDB_IPOD_GENERATION_TOUCH_3:
+        case ITDB_IPOD_GENERATION_TOUCH_4:
         case ITDB_IPOD_GENERATION_IPHONE_1:
         case ITDB_IPOD_GENERATION_IPHONE_2:
         case ITDB_IPOD_GENERATION_IPHONE_3:
@@ -2157,6 +2196,7 @@ gboolean itdb_device_is_iphone_family (const Itdb_Device *device)
 	    case ITDB_IPOD_GENERATION_NANO_3:
 	    case ITDB_IPOD_GENERATION_NANO_4:
 	    case ITDB_IPOD_GENERATION_NANO_5:
+	    case ITDB_IPOD_GENERATION_NANO_6:
 	    case ITDB_IPOD_GENERATION_SHUFFLE_1:
 	    case ITDB_IPOD_GENERATION_SHUFFLE_2:
 	    case ITDB_IPOD_GENERATION_SHUFFLE_3:
@@ -2170,6 +2210,7 @@ gboolean itdb_device_is_iphone_family (const Itdb_Device *device)
 	    case ITDB_IPOD_GENERATION_TOUCH_1:
 	    case ITDB_IPOD_GENERATION_TOUCH_2:
 	    case ITDB_IPOD_GENERATION_TOUCH_3:
+	    case ITDB_IPOD_GENERATION_TOUCH_4:
 	    case ITDB_IPOD_GENERATION_IPHONE_1:
 	    case ITDB_IPOD_GENERATION_IPHONE_2:
 	    case ITDB_IPOD_GENERATION_IPHONE_3:
@@ -2209,6 +2250,7 @@ enum ItdbShadowDBVersion itdb_device_get_shadowdb_version (const Itdb_Device *de
 	    case ITDB_IPOD_GENERATION_NANO_3:
 	    case ITDB_IPOD_GENERATION_NANO_4:
 	    case ITDB_IPOD_GENERATION_NANO_5:
+	    case ITDB_IPOD_GENERATION_NANO_6:
 	    case ITDB_IPOD_GENERATION_VIDEO_1:
 	    case ITDB_IPOD_GENERATION_VIDEO_2:
 	    case ITDB_IPOD_GENERATION_CLASSIC_1:
@@ -2217,6 +2259,7 @@ enum ItdbShadowDBVersion itdb_device_get_shadowdb_version (const Itdb_Device *de
 	    case ITDB_IPOD_GENERATION_TOUCH_1:
 	    case ITDB_IPOD_GENERATION_TOUCH_2:
 	    case ITDB_IPOD_GENERATION_TOUCH_3:
+	    case ITDB_IPOD_GENERATION_TOUCH_4:
 	    case ITDB_IPOD_GENERATION_IPHONE_1:
 	    case ITDB_IPOD_GENERATION_IPHONE_2:
 	    case ITDB_IPOD_GENERATION_IPHONE_3:
