@@ -91,6 +91,7 @@ typedef struct
     GList *pos_glist;    /* temporary list to store position indicators */
     GList *tracks;       /* temporary list to store tracks */
     GList *playcounts;   /* contents of Play Counts file */
+    GHashTable *pcounts2;/* contents of the PlayCounts.plist file */
     GTree *idtree;       /* temporary tree with track id tree */
     GError *error;       /* where to report errors to */
 } FImport;
@@ -240,7 +241,12 @@ G_GNUC_INTERNAL gboolean itdb_hash58_write_hash (Itdb_Device *device,
 						 GError **error);
 G_GNUC_INTERNAL gboolean itdb_hash72_compute_hash_for_sha1 (const Itdb_Device *device, 
 							    const guchar sha1[20],
-							    guchar signature[46]);
+							    guchar signature[46],
+							    GError **error);
+
+G_GNUC_INTERNAL GByteArray *itdb_chapterdata_build_chapter_blob(Itdb_Chapterdata *chapterdata,
+								gboolean reversed);
+
 #ifdef HAVE_LIBIMOBILEDEVICE
 G_GNUC_INTERNAL int itdb_iphone_start_sync(Itdb_Device *device, void **prepdata);
 G_GNUC_INTERNAL int itdb_iphone_stop_sync(void *sync_ctx);
