@@ -361,8 +361,10 @@ static int mk_Extras(Itdb_iTunesDB *itdb, const char *outpath)
     int rebuild = 0;
     gchar *dbf = NULL;
     sqlite3 *db = NULL;
+    sqlite3_stmt *stmt_chapter = NULL;
     char *errmsg = NULL;
     struct stat fst;
+    GList *gl = NULL;
 
     dbf = g_build_filename(outpath, "Extras.itdb", NULL);
     printf("[%s] Processing '%s'\n", __func__, dbf);
@@ -398,10 +400,13 @@ static int mk_Extras(Itdb_iTunesDB *itdb, const char *outpath)
     }
 
     sqlite3_exec(db, "BEGIN;", NULL, NULL, NULL);
+    if (SQLITE_OK != sqlite3_prepare_v2(db, "INSERT INTO \"chapter\" VALUES(?,?);", -1, &stmt_chapter, NULL)) {
+	fprintf(stderr, "[%s] sqlite3_prepare error: %s\n", __func__, sqlite3_errmsg(db));
+	goto leave;
+    }
 
     /* kill all entries in 'chapter' as they will be re-inserted */
-    /* TODO: we do not support this in the moment, so don't touch this */
-    /*if (SQLITE_OK != sqlite3_exec(db, "DELETE FROM chapter;", NULL, NULL, &errmsg)) {
+    if (SQLITE_OK != sqlite3_exec(db, "DELETE FROM chapter;", NULL, NULL, &errmsg)) {
 	fprintf(stderr, "[%s] sqlite3_exec error: %s\n", __func__, sqlite3_errmsg(db));
 	if (errmsg) {
 	    fprintf(stderr, "[%s] additional error information: %s\n", __func__, errmsg);
@@ -409,7 +414,7 @@ static int mk_Extras(Itdb_iTunesDB *itdb, const char *outpath)
 	    errmsg = NULL;
 	}
 	goto leave;
-    }*/
+    }
 
     /* kill all entries in 'lyrics' as they will be re-inserted */
     /* TODO: we do not support this in the moment, so don't touch this */
@@ -423,11 +428,38 @@ static int mk_Extras(Itdb_iTunesDB *itdb, const char *outpath)
 	goto leave;
     }*/
 
+    for (gl = itdb->tracks; gl; gl = gl->next) {
+	Itdb_Track *track = gl->data;
+	if (track->chapterdata) {
+	    int idx = 0;
+	    GByteArray *chapter_blob = itdb_chapterdata_build_chapter_blob(track->chapterdata, FALSE);
+	    /* printf("[%s] -- inserting into \"chapter\"\n", __func__); */
+	    res = sqlite3_reset(stmt_chapter);
+	    if (res != SQLITE_OK) {
+		fprintf(stderr, "[%s] 1 sqlite3_reset returned %d\n", __func__, res);
+	    }
+	    /* item_pid INTEGER NOT NULL */
+	    sqlite3_bind_int64(stmt_chapter, ++idx, track->dbid);
+	    /* data BLOB */
+	    sqlite3_bind_blob(stmt_chapter, ++idx, chapter_blob->data, chapter_blob->len, SQLITE_TRANSIENT);
+
+	    res = sqlite3_step(stmt_chapter);
+	    if (res == SQLITE_DONE) {
+		/* expected result */
+	    } else {
+		fprintf(stderr, "[%s] 8 sqlite3_step returned %d\n", __func__, res);
+	    }
+	    g_byte_array_free(chapter_blob, TRUE);
+	}
+    }
     sqlite3_exec(db, "COMMIT;", NULL, NULL, NULL);
 
     res = 0;
     printf("[%s] done.\n", __func__);
 leave:
+    if (stmt_chapter) {
+	sqlite3_finalize(stmt_chapter);
+    }
     if (db) {
 	sqlite3_close(db);
     }
@@ -1264,11 +1296,11 @@ static int mk_Library(Itdb_iTunesDB *itdb,
 	    /* series_name TEXT */
 	    sqlite3_bind_text(stmt_video_info, ++idx, track->tvshow, -1, SQLITE_STATIC);
 	    /* sort_series_name TEXT */
-	    sqlite3_bind_text(stmt_video_info, ++idx, track->sort_tvshow, -1, SQLITE_STATIC);
+	    bind_first_text(stmt_item, ++idx, 2, track->sort_tvshow, track->tvshow);
 	    /* episode_id TEXT */
 	    sqlite3_bind_text(stmt_video_info, ++idx, track->tvepisode, -1, SQLITE_STATIC);
 	    /* episode_sort_id INTEGER */
-	    sqlite3_bind_int(stmt_video_info, ++idx, track->episode_nr);
+	    sqlite3_bind_int(stmt_video_info, ++idx, track->season_nr << 16 | track->episode_nr);
 	    /* network_name TEXT */
 	    sqlite3_bind_text(stmt_video_info, ++idx, track->tvnetwork, -1, SQLITE_STATIC);
 	    /* extended_content_rating TEXT */
@@ -1876,7 +1908,7 @@ static gboolean mk_Locations_cbk(Itdb_iTunesDB *itdb, const char *dirname)
     final_sha1 = &g_array_index(cbk, guchar, CBK_HEADER_SIZE);
     cbk_hash72 = &g_array_index(cbk, guchar, 0);
     success = itdb_hash72_compute_hash_for_sha1 (itdb->device, final_sha1,
-						 cbk_hash72);
+						 cbk_hash72, NULL);
     if (!success) {
 	g_array_free(cbk, TRUE);
 	return FALSE;
@@ -1924,38 +1956,41 @@ static int build_itdb_files(Itdb_iTunesDB *itdb,
     return 0;
 }
 
-static int ensure_itlp_dir_exists(const char *itlpdir)
+static int ensure_itlp_dir_exists(const char *itlpdir, GError **error)
 {
     /* check if directory exists */
     if (!g_file_test(itlpdir, G_FILE_TEST_EXISTS)) {
 	if (g_mkdir(itlpdir, 0755) != 0) {
-		fprintf(stderr, "Could not create directory '%s': %s\n", itlpdir, strerror(errno));
-		return FALSE;
+	    g_set_error (error, G_FILE_ERROR,
+			 g_file_error_from_errno(errno),
+			 "Could not create directory '%s': %s",
+			 itlpdir, strerror(errno));
+	    return FALSE;
 	}
     } else if (!g_file_test(itlpdir, G_FILE_TEST_IS_DIR)) {
-	    fprintf(stderr, "'%s' is not a directory as it should be!\n", itlpdir);
-	    return FALSE;
+	g_set_error (error, G_FILE_ERROR, G_FILE_ERROR_NOTDIR,
+		     "'%s' is not a directory as it should be",
+		     itlpdir);
+	return FALSE;
     }
 
     return TRUE;
 }
 
-static int copy_itdb_file(gchar *from_dir, gchar *to_dir, gchar *fname)
+static int copy_itdb_file(const gchar *from_dir, const gchar *to_dir,
+			  const gchar *fname, GError **error)
 {
     int res = 0;
 
     gchar *srcname = g_build_filename(from_dir, fname, NULL);
     gchar *dstname = g_build_filename(to_dir, fname, NULL);
-    GError *error = NULL;
 
-    if (itdb_cp(srcname, dstname, &error)) {
+    if (itdb_cp(srcname, dstname, error)) {
 	fprintf(stderr, "itdbprep: copying '%s'\n", fname);
 	res++;
     }
-
-    if (error) {
-	fprintf(stderr, "Error copying '%s' to '%s': %s\n", srcname, dstname, error->message);
-	g_error_free(error);
+    if (error && *error) {
+	fprintf(stderr, "Error copying '%s' to '%s': %s\n", srcname, dstname, (*error)->message);
     }
 
     if (srcname) {
@@ -2009,7 +2044,7 @@ int itdb_sqlite_generate_itdbs(FExport *fexp)
 
     printf("itlp directory='%s'\n", itlpdir);
 
-    if (!ensure_itlp_dir_exists(itlpdir)) {
+    if (!ensure_itlp_dir_exists(itlpdir, &fexp->error)) {
 	res = -1;
 	goto leave;
     }
@@ -2023,7 +2058,9 @@ int itdb_sqlite_generate_itdbs(FExport *fexp)
 
     tmpdir = g_build_path(g_get_tmp_dir(), tmpnam(NULL), NULL);
     if (g_mkdir(tmpdir, 0755) != 0) {
-	fprintf(stderr, "Could not create temporary directory '%s': %s\n", tmpdir, strerror(errno));
+	g_set_error (&fexp->error, G_FILE_ERROR, g_file_error_from_errno(errno),
+		     "Could not create temporary directory '%s': %s",
+		     tmpdir, strerror(errno));
 	res = -1;
 	goto leave;
     }
@@ -2031,19 +2068,31 @@ int itdb_sqlite_generate_itdbs(FExport *fexp)
     /* generate itdb files in temporary directory */
     if (build_itdb_files(fexp->itdb, fexp->albums, fexp->artists, fexp->composers, tmpdir,
 		     itdb_device_get_uuid(fexp->itdb->device)) != 0) {
+	g_set_error (&fexp->error, ITDB_ERROR, ITDB_ERROR_SQLITE,
+		     "Failed to generate sqlite database");
 	res = -1;
 	goto leave;
     } else {
 	/* copy files */
-	int cpcnt = 0;
-	cpcnt += copy_itdb_file(tmpdir, itlpdir, "Dynamic.itdb");
-	cpcnt += copy_itdb_file(tmpdir, itlpdir, "Extras.itdb");
-	cpcnt += copy_itdb_file(tmpdir, itlpdir, "Genius.itdb");
-	cpcnt += copy_itdb_file(tmpdir, itlpdir, "Library.itdb");
-	cpcnt += copy_itdb_file(tmpdir, itlpdir, "Locations.itdb");
-	cpcnt += copy_itdb_file(tmpdir, itlpdir, "Locations.itdb.cbk");
-	if (cpcnt != 6) {
-	    res = -1;
+	const char *itdb_files[] = { "Dynamic.itdb", "Extras.itdb",
+				     "Genius.itdb", "Library.itdb",
+				     "Locations.itdb", "Locations.itdb.cbk",
+				     NULL };
+	const char **file;
+	GError *error = NULL;
+	g_assert (fexp->error == NULL);
+	for (file = itdb_files; *file != NULL; file++) {
+	    copy_itdb_file(tmpdir, itlpdir, *file, &error);
+	    if (error) {
+		res = -1;
+		/* only the last error will be reported, but this way we
+		 * copy as many files as possible even when errors occur
+		 */
+		g_clear_error (&fexp->error);
+		g_propagate_error (&fexp->error, error);
+	    }
+	}
+	if (fexp->error) {
 	    goto leave;
 	}
     }
